<div class="checkbox">
  <label>
    <input type="checkbox" value="" checked>
    Lorem ipsum dolor sit amet, leo in, in vivamus.
  </label>
</div>
<div class="checkbox">
  <label>
    <input type="checkbox" value="" checked>
    Nec sapien ante.
  </label>
</div>
<div class="checkbox">
  <label>
    <input type="checkbox" value="">
    Consequat sem ipsum.
  </label>
</div>
