<div class="field-sortable">
  {{#each items as |field|}}
    {{sortable-field field=field currentField=targetController.currentField onClick=(action 'editField' target=targetController) onDeleteClick=(action 'deleteField' target=targetController) onOrderInvalidated=(action 'triggerUpdateSortable')}}
  {{else}}
    <div class="row">
      <div class="col-xs-12 no-records">
        <h4>This form doesn't have any fields</h4>
        <p>Click on the options in the 'Add Fields' panel to the right to add one</p>
      </div>
    </div>
  {{/each}}
</div>
