<div class="row formulaic-row edit-rules">
  <div class="col-xs-8 preview-column">
    <h2>Editing Rules</h2>

    {{sortable-rules items=activeRules targetController=this}}

    <div class="custom-edit-block">
      <button class="btn btn-link" {{action "addRule"}}>
        <span class="glyphicon glyphicon-plus-sign"></span>
        Add Rule
      </button>
    </div>

    <div class="row formulaic-controls">
      <div class="col-xs-12">
        <button class="btn btn-primary" type="submit" {{action "saveRules" true}} disabled={{controlsDisabled}}>
          {{#if saveContinueActive}}Saving...{{else}}Save &amp; Continue Editing{{/if}}
        </button>
        <button class="btn btn-primary" type="submit" {{action "saveRules" false}} disabled={{controlsDisabled}}>
          {{#if saveActive}}Saving...{{else}}Save{{/if}}
        </button>
        <button class="btn btn-danger" type="submit" {{action "closeRules"}} disabled={{controlsDisabled}}>Close</button>
      </div>
    </div>
  </div>
</div>
