<div class="rule-sortable rule-list">
  {{#each items as |rule|}}
    {{sortable-rule rule=rule allFields=allFields targetController=targetController onDeleteClick=(action 'deleteRule' target=targetController) onOrderInvalidated=(action 'triggerUpdateSortable') onAddRuleClick=(action 'addRule' target=targetController) onAddConditionClick=(action 'addCondition' target=targetController) onAddResultClick=(action 'addResult' target=targetController)}}
  {{else}}
    <div class="row">
      <div class="col-xs-12 no-records">
        <h4>This form doesn't have any rules</h4>
      </div>
    </div>
  {{/each}}
</div>
