<div class="row formulaic-row edit-fields">
  <div class="col-xs-8 preview-column">
    <h2>Editing Fields</h2>
    <div class="custom-edit-block">
      {{sortable-fields items=activeFields targetController=this}}
    </div>

    <div class="row formulaic-controls">
      <div class="col-xs-12">
        <button class="btn btn-primary" type="submit" {{action "saveFields" true}} disabled={{controlsDisabled}}>
          {{#if saveContinueActive}}Saving...{{else}}Save &amp; Continue Editing{{/if}}
        </button>
        <button class="btn btn-primary" type="submit" {{action "saveFields" false}} disabled={{controlsDisabled}}>
          {{#if saveActive}}Saving...{{else}}Save{{/if}}
        </button>
        <button class="btn btn-danger" type="submit" {{action "close"}} disabled={{controlsDisabled}}>Close</button>
      </div>
    </div>
  </div>

  <div class="col-xs-4">
    <div class="edit-column">
        {{outlet "sidebar"}}
    </div>
  </div>
</div>
