#edit_fields_dialog {
    display: none;
}

.formulaic-fields {
    border: 1px solid #ccc;
    padding:10px 10px 0;
}
.formulaic-fields > div {
    border: 1px solid #ccc;
    margin:0 0 10px;
}

/*.formulaic-tools {
    float:right;
    top:-25px;
    position: relative;
    padding:0 5px 0 0;
}
.formulaic-tools li {
    float:right;
}
.formulaic-close, .formulaic-move {
    background: url("../images/icons-grappelli.png") no-repeat scroll 0 0 rgba(0, 0, 0, 0);
    width:24px;
    height:24px;
    display: inline-block;
}
.formulaic-close {
    background-position: 0 -3003px;
}
.formulaic-close:hover {
    background-position: 0 -3047px;
}
.formulaic-move {
    background-position: 0 -2215px;
}
.formulaic-move:hover {
    background-position: 0 -2695px;
}*/
.formulaic-content {
    background-color:#fff;
    padding:10px;
}