# Generated by Django 3.1.3 on 2020-12-07 22:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('formulaic', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='field',
            name='enabled',
            field=models.BooleanField(default=True),
        ),
    ]
