<div class="checkbox">
  <label>
    {{input type="checkbox" checked=completeField.default_checked disabled=true}}
    {{{completeField.display_name}}}

    {{#if completeField.required}}
      <span class="text-danger">*</span>
    {{/if}}
  </label>
</div>
