{{input type="hidden" value=field.position class="position"}}
<ul class="controls list-inline">
  <li>
    <button class="btn btn-xs btn-link" {{action "clickedDeleteField" field completeField bubbles=false}}>
      <span class="glyphicon glyphicon-trash"></span>
    </button>
  </li>
</ul>

{{#if completeField.data_name}}
  <span class="data-name">({{completeField.data_name}})</span>
{{/if}}

<div class="col-xs-6">
  {{#if showDisplayName }}
    <label>
      {{#if completeField.display_name}}
        {{{completeField.display_name}}}
      {{else}}
        <span class="empty">(Field Name)</span>
      {{/if}}
      {{#if completeField.required}}
        <span class="text-danger">*</span>
      {{/if}}
    </label>
  {{/if}}
  {{component previewComponent completeField=completeField}}
</div>
