<h2>Add Fields</h2>
<h3>Basic</h3>
<button class="btn btn-default btn-block" type="submit" {{action "createTextField" "text"}}>Text (Single Line)</button>
<button class="btn btn-default btn-block" type="submit" {{action "createTextField" "textarea"}}>Text (Multi Line)</button>
<button class="btn btn-default btn-block" type="submit" {{action "createChoiceField" "select"}}>Dropdown List</button>
<button class="btn btn-default btn-block" type="submit" {{action "createChoiceField" "radio_select"}}>Radio List</button>
<button class="btn btn-default btn-block" type="submit" {{action "createChoiceField" "checkbox_select_multiple"}}>Checkbox List</button>
<button class="btn btn-default btn-block" type="submit" {{action "createBooleanField" "checkbox"}}>Checkbox</button>
<button class="btn btn-default btn-block" type="submit" {{action "createChoiceField" "select_multiple"}}>Multi-select List</button>
<button class="btn btn-default btn-block" type="submit" {{action "createHiddenField" "hidden"}}>Hidden Field</button>

<h3>Typed</h3>
<button class="btn btn-default btn-block" type="submit" {{action "createTextField" "full_name"}}>Full Name</button>
<button class="btn btn-default btn-block" type="submit" {{action "createTextField" "email"}}>Email</button>
<button class="btn btn-default btn-block" type="submit" {{action "createTextField" "phone_number"}}>Phone Number</button>
<button class="btn btn-default btn-block" type="submit" {{action "createTextField" "integer"}}>Integer</button>
