<div class="radio">
  <label>
    <input type="radio" name="optionsRadios" id="optionsRadios1" value="option1" checked>
    {{#if field.completeField.default_option}}
      {{field.completeField.default_option.name}}
    {{else}}
      {{#if field.completeField.default_text}}
        {{field.completeField.default_text}}
      {{else}}
        Lorem ipsum dolor sit amet, leo in, in vivamus.
      {{/if}}
    {{/if}}
  </label>
</div>
<div class="radio">
  <label>
    <input type="radio" name="optionsRadios" id="optionsRadios2" value="option1">
    Nec sapien ante.
  </label>
</div>
<div class="radio">
  <label>
    <input type="radio" name="optionsRadios" id="optionsRadios3" value="option1">
    Consequat sem ipsum.
  </label>
</div>
